@@ -59,11 +59,11 @@ class AccountModel : public QAbstractListModel
 
         AccountModel(QObject* parent);
         ~AccountModel();
-        virtual int rowCount(const QModelIndex& parent = QModelIndex()) const;
-        virtual QVariant data(const QModelIndex& index, int role) const;
-        virtual QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const;
-        virtual bool setData(const QModelIndex& index, const QVariant& value, int role = Qt::EditRole);
-        virtual bool removeRows(int row, int count, const QModelIndex& parent = QModelIndex());
+        int rowCount(const QModelIndex& parent = QModelIndex()) const Q_DECL_OVERRIDE;
+        QVariant data(const QModelIndex& index, int role) const Q_DECL_OVERRIDE;
+        QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
+        bool setData(const QModelIndex& index, const QVariant& value, int role = Qt::EditRole) Q_DECL_OVERRIDE;
+        bool removeRows(int row, int count, const QModelIndex& parent = QModelIndex()) Q_DECL_OVERRIDE;
         bool removeAccountKeepingFiles(int row, bool keepFile = false);
 
         QVariant newUserData(int role) const;
